/** @jsx jsx */
import { useRef } from 'react';

// eslint-disable-next-line @atlaskit/ui-styling-standard/use-compiled -- Ignored via go/DSP-18766
import { jsx } from '@emotion/react';
import { injectIntl } from 'react-intl-next';
import { useSharedPluginState } from '@atlaskit/editor-common/hooks';
import { getAriaKeyshortcuts, toggleHighlightPalette, tooltip } from '@atlaskit/editor-common/keymaps';
import { highlightMessages as messages } from '@atlaskit/editor-common/messages';
import { expandIconWrapperStyle } from '@atlaskit/editor-common/styles';
import { TOOLBAR_BUTTON, ToolbarButton } from '@atlaskit/editor-common/ui-menu';
import { hexToEditorTextBackgroundPaletteColor } from '@atlaskit/editor-palette';
import ExpandIcon from '@atlaskit/icon/glyph/chevron-down';
import { Flex } from '@atlaskit/primitives';
import { setPalette } from '../commands';
import { EditorHighlightIcon } from './shared/EditorHighlightIcon';
import { PaletteDropdown } from './shared/PaletteDropdown';
import { useDropdownEvents } from './shared/useDropdownEvents';
const PrimaryToolbarHighlightColor = ({
  popupsMountPoint,
  popupsBoundariesElement,
  popupsScrollableElement,
  isToolbarReducedSpacing,
  disabled,
  pluginInjectionApi,
  intl: {
    formatMessage
  },
  editorView
}) => {
  const toolbarItemRef = useRef(null);
  const {
    highlightState
  } = useSharedPluginState(pluginInjectionApi, ['highlight']);
  const setDropdownOpen = isOpen => {
    if (!(highlightState !== null && highlightState !== void 0 && highlightState.disabled)) {
      const {
        state,
        dispatch
      } = editorView;
      setPalette(pluginInjectionApi, isOpen)(state, dispatch);
    }
  };
  const isDropdownOpen = !!(highlightState !== null && highlightState !== void 0 && highlightState.isPaletteOpen);
  const {
    handleClick,
    handleKeyDown,
    handleClickOutside,
    handleEscapeKeydown,
    handleColorChange,
    isOpenedByKeyboard
  } = useDropdownEvents({
    toolbarItemRef,
    setIsDropdownOpen: setDropdownOpen,
    isDropdownOpen,
    pluginInjectionApi
  });

  // Don't render the toolbar option while the plugin is initialising
  if (!highlightState) {
    return null;
  }
  const toolbarButtonLabel = formatMessage(messages.highlight);

  // Get the design token for the  active color (if it exists) to modify the toolbar
  // icon, but show the nice rainbow if none is selected
  const activeColorToken = highlightState.activeColor === null ? null : hexToEditorTextBackgroundPaletteColor(highlightState.activeColor);
  return jsx(Flex, {
    alignItems: "center"
  }, jsx(PaletteDropdown, {
    popupsMountPoint: popupsMountPoint,
    popupsBoundariesElement: popupsBoundariesElement,
    popupsScrollableElement: popupsScrollableElement,
    isOpen: isDropdownOpen && !highlightState.disabled,
    activeColor: highlightState.activeColor,
    trigger: jsx(ToolbarButton, {
      buttonId: TOOLBAR_BUTTON.BACKGROUND_COLOR,
      spacing: isToolbarReducedSpacing ? 'none' : 'default',
      disabled: disabled || highlightState.disabled,
      selected: isDropdownOpen,
      "aria-label": tooltip(toggleHighlightPalette, toolbarButtonLabel),
      "aria-keyshortcuts": getAriaKeyshortcuts(toggleHighlightPalette),
      "aria-expanded": isDropdownOpen,
      "aria-haspopup": true,
      title: tooltip(toggleHighlightPalette, toolbarButtonLabel),
      onClick: handleClick,
      onKeyDown: handleKeyDown,
      ref: toolbarItemRef,
      iconBefore: jsx(Flex, null, jsx(EditorHighlightIcon, {
        selectedColor: activeColorToken,
        disabled: highlightState.disabled
      }), jsx("span", {
        css: expandIconWrapperStyle
      }, jsx(ExpandIcon, {
        label: ""
      })))
    }),
    onColorChange: color => handleColorChange(color),
    isOpenedByKeyboard: isOpenedByKeyboard,
    handleClickOutside: handleClickOutside,
    handleEscapeKeydown: handleEscapeKeydown
  }));
};
export const PrimaryToolbarHighlightColorWithIntl = injectIntl(PrimaryToolbarHighlightColor);