import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
/** @jsx jsx */
import { useRef, useState } from 'react';

// eslint-disable-next-line @atlaskit/ui-styling-standard/use-compiled -- Ignored via go/DSP-18766
import { jsx } from '@emotion/react';
import { injectIntl } from 'react-intl-next';
import { useSharedPluginState } from '@atlaskit/editor-common/hooks';
import { highlightMessages as messages } from '@atlaskit/editor-common/messages';
import { expandIconWrapperStyle } from '@atlaskit/editor-common/styles';
import { TOOLBAR_BUTTON, ToolbarButton } from '@atlaskit/editor-common/ui-menu';
import { hexToEditorTextBackgroundPaletteColor } from '@atlaskit/editor-palette';
import ExpandIcon from '@atlaskit/icon/glyph/chevron-down';
import { Flex } from '@atlaskit/primitives';
import { EditorHighlightIcon } from './shared/EditorHighlightIcon';
import { PaletteDropdown } from './shared/PaletteDropdown';
import { useDropdownEvents } from './shared/useDropdownEvents';
var FloatingToolbarHighlightColor = function FloatingToolbarHighlightColor(_ref) {
  var pluginInjectionApi = _ref.pluginInjectionApi,
    formatMessage = _ref.intl.formatMessage;
  var toolbarItemRef = useRef(null);
  var _useSharedPluginState = useSharedPluginState(pluginInjectionApi, ['highlight']),
    highlightState = _useSharedPluginState.highlightState;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isDropdownOpen = _useState2[0],
    setIsDropdownOpen = _useState2[1];
  var _useDropdownEvents = useDropdownEvents({
      toolbarItemRef: toolbarItemRef,
      setIsDropdownOpen: setIsDropdownOpen,
      isDropdownOpen: isDropdownOpen,
      pluginInjectionApi: pluginInjectionApi
    }),
    handleClick = _useDropdownEvents.handleClick,
    handleKeyDown = _useDropdownEvents.handleKeyDown,
    handleClickOutside = _useDropdownEvents.handleClickOutside,
    handleEscapeKeydown = _useDropdownEvents.handleEscapeKeydown,
    handleColorChange = _useDropdownEvents.handleColorChange,
    isOpenedByKeyboard = _useDropdownEvents.isOpenedByKeyboard;

  // Don't render the toolbar option while the plugin is initialising
  if (!highlightState) {
    return null;
  }
  var toolbarButtonLabel = formatMessage(messages.highlight);

  // Get the design token for the  active color (if it exists) to modify the toolbar
  // icon, but show the nice rainbow if none is selected
  var activeColorToken = highlightState.activeColor === null ? null : hexToEditorTextBackgroundPaletteColor(highlightState.activeColor);
  return jsx(Flex, {
    alignItems: "center"
  }, jsx(PaletteDropdown, {
    isOpen: isDropdownOpen && !highlightState.disabled,
    activeColor: highlightState.activeColor,
    trigger: jsx(ToolbarButton, {
      buttonId: TOOLBAR_BUTTON.BACKGROUND_COLOR,
      spacing: 'default',
      disabled: highlightState.disabled,
      selected: isDropdownOpen,
      "aria-label": toolbarButtonLabel,
      "aria-expanded": isDropdownOpen,
      "aria-haspopup": true,
      title: toolbarButtonLabel,
      onClick: handleClick,
      onKeyDown: handleKeyDown,
      ref: toolbarItemRef,
      iconBefore: jsx(Flex, null, jsx(EditorHighlightIcon, {
        selectedColor: activeColorToken,
        disabled: highlightState.disabled
      }), jsx("span", {
        css: expandIconWrapperStyle
      }, jsx(ExpandIcon, {
        label: ""
      })))
    }, formatMessage(messages.highlightFloatingToolbar)),
    onColorChange: function onColorChange(color) {
      return handleColorChange(color);
    },
    isOpenedByKeyboard: isOpenedByKeyboard,
    handleClickOutside: handleClickOutside,
    handleEscapeKeydown: handleEscapeKeydown
  }));
};
export var FloatingToolbarHighlightColorWithIntl = injectIntl(FloatingToolbarHighlightColor);